@@ -1,7 +1,6 @@
 from typing import Any, Dict, Optional, Tuple, Union
 
 import numpy as np
-import numpy.typing as npt
 import pandas as pd
 from pydantic import Field, root_validator, validator
 
@@ -68,10 +67,7 @@ def _compute_coordinate_and_axis_labels_for_pandas_index(pandas_index: pd.Index)
         axis_labels: axis labels
     """
     coordinate_labels: CoordinateLabels = tuple(
-        map(
-            tuple,
-            [pandas_index.unique(level=level).tolist() for level in range(pandas_index.nlevels)],
-        )
+        map(tuple, [pandas_index.unique(level=level).tolist() for level in range(pandas_index.nlevels)])
     )
     axis_labels = tuple(pandas_index.names)
 
@@ -102,8 +98,8 @@ class TimeArray(BaseModel):
     start_time: Time
     end_time: Time
     as_of_time: Time
-    values: npt.NDArray[np.float64]
-    mask: Optional[npt.NDArray[np.int8]] = None
+    values: np.ndarray
+    mask: Optional[np.ndarray] = None
     coordinate_labels: CoordinateLabels = Field(None)
     axis_labels: AxisLabels = Field(None)
 
@@ -193,8 +189,8 @@ class TimeArray(BaseModel):
         start_time: Optional[Time] = values.get("start_time", None)
         end_time: Optional[Time] = values.get("end_time", None)
         sample_period: Optional[TimeDelta] = values.get("sample_period", None)
-        data: Optional[npt.NDArray[np.float64]] = values.get("values", None)
-        mask: Optional[npt.NDArray[np.int8]] = values.get("mask", None)
+        data: Optional[np.ndarray] = values.get("values", None)
+        mask: Optional[np.ndarray] = values.get("mask", None)
 
         if start_time and end_time and sample_period and data is not None:
             check_arrays_same_length_as_time_range(
