@@ -9,10 +9,10 @@ from myst.models import base_model
 class ModelCreate(base_model.BaseModel):
     """Schema for model create requests."""
 
-    object_: Literal["Node"] = Field(..., alias="object")
-    type: Literal["Model"]
     title: str
     project: str
     connector_uuid: str
+    object_: Optional[Literal["Node"]] = Field("Node", alias="object")
+    type: Optional[Literal["Model"]] = "Model"
     description: Optional[str] = None
     parameters: Optional[Any] = None
