@@ -6,6 +6,7 @@ from typing_extensions import Literal
 from myst.models import base_model
 
 from ..models.absolute_timing_get import AbsoluteTimingGet
+from ..models.cron_timing_get import CronTimingGet
 from ..models.relative_timing_get import RelativeTimingGet
 
 
@@ -17,7 +18,7 @@ class ModelFitPolicyGet(base_model.BaseModel):
     create_time: str
     type: Literal["ModelFitPolicy"]
     creator: str
-    schedule_timing: Union[AbsoluteTimingGet, RelativeTimingGet]
+    schedule_timing: Union[AbsoluteTimingGet, RelativeTimingGet, CronTimingGet]
     active: bool
     node: str
     start_timing: Union[AbsoluteTimingGet, RelativeTimingGet]
