@@ -1,4 +1,4 @@
-from typing import Any, Optional
+from typing import Any, List, Optional
 
 from pydantic import Field
 from typing_extensions import Literal
@@ -6,6 +6,7 @@ from typing_extensions import Literal
 from myst.models import base_model
 
 from ..models.deploy_status import DeployStatus
+from ..models.time_dataset_spec import TimeDatasetSpec
 
 
 class ModelGet(base_model.BaseModel):
@@ -23,5 +24,7 @@ class ModelGet(base_model.BaseModel):
     deploy_status: DeployStatus
     connector_uuid: str
     parameters: Any
+    input_specs_schema: Any
     update_time: Optional[str] = None
     description: Optional[str] = None
+    output_specs: Optional[List[TimeDatasetSpec]] = None
