@@ -1,4 +1,4 @@
-from typing import Any, Optional
+from typing import Any, List, Optional
 
 from pydantic import Field
 from typing_extensions import Literal
@@ -6,6 +6,7 @@ from typing_extensions import Literal
 from myst.models import base_model
 
 from ..models.deploy_status import DeployStatus
+from ..models.time_dataset_spec import TimeDatasetSpec
 
 
 class ModelUpdate(base_model.BaseModel):
@@ -24,3 +25,5 @@ class ModelUpdate(base_model.BaseModel):
     deploy_status: Optional[DeployStatus] = None
     connector_uuid: Optional[str] = None
     parameters: Optional[Any] = None
+    output_specs: Optional[List[TimeDatasetSpec]] = None
+    input_specs_schema: Optional[Any] = None
