@@ -9,10 +9,10 @@ from myst.models import base_model
 class OperationCreate(base_model.BaseModel):
     """Schema for operation create requests."""
 
-    object_: Literal["Node"] = Field(..., alias="object")
-    type: Literal["Operation"]
     title: str
     project: str
     connector_uuid: str
+    object_: Optional[Literal["Node"]] = Field("Node", alias="object")
+    type: Optional[Literal["Operation"]] = "Operation"
     description: Optional[str] = None
     parameters: Optional[Any] = None
