@@ -6,6 +6,7 @@ from typing_extensions import Literal
 from myst.models import base_model
 
 from ..models.deploy_status import DeployStatus
+from ..models.org_sharing_role import OrgSharingRole
 
 
 class ProjectGet(base_model.BaseModel):
@@ -19,5 +20,7 @@ class ProjectGet(base_model.BaseModel):
     title: str
     creator: str
     deploy_status: DeployStatus
+    organization_sharing_enabled: bool
     update_time: Optional[str] = None
     description: Optional[str] = None
+    organization_sharing_role: Optional[OrgSharingRole] = None
