@@ -6,6 +6,7 @@ from typing_extensions import Literal
 from myst.models import base_model
 
 from ..models.deploy_status import DeployStatus
+from ..models.org_sharing_role import OrgSharingRole
 
 
 class ProjectUpdate(base_model.BaseModel):
@@ -19,5 +20,7 @@ class ProjectUpdate(base_model.BaseModel):
     owner: Optional[str] = None
     title: Optional[str] = None
     description: Optional[str] = None
+    organization_sharing_enabled: Optional[bool] = None
+    organization_sharing_role: Optional[OrgSharingRole] = None
     creator: Optional[str] = None
     deploy_status: Optional[DeployStatus] = None
