@@ -9,8 +9,8 @@ from myst.models import base_model
 class RelativeTimingCreate(base_model.BaseModel):
     """Relative timing schema for create requests."""
 
-    object_: Literal["Timing"] = Field(..., alias="object")
     type: Literal["RelativeTiming"]
+    object_: Optional[Literal["Timing"]] = Field("Timing", alias="object")
     frequency: Optional[str] = None
     offset: Optional[str] = None
     time_zone: Optional[str] = "UTC"
