@@ -9,8 +9,8 @@ from myst.models import base_model
 class RelativeTimingGet(base_model.BaseModel):
     """Relative timing schema for get responses."""
 
-    object_: Literal["Timing"] = Field(..., alias="object")
-    type: Literal["RelativeTiming"]
     time_zone: str
+    object_: Optional[Literal["Timing"]] = Field("Timing", alias="object")
+    type: Optional[Literal["RelativeTiming"]] = "RelativeTiming"
     frequency: Optional[str] = None
     offset: Optional[str] = None
