@@ -12,9 +12,9 @@ def use_fake_credentials() -> None:
     myst.set_client(myst.Client(credentials=FakeCredentials()))
 
 
-@pytest.fixture
+@pytest.fixture(autouse=True)
 def mock_api() -> Generator[MockRouter, None, None]:
-    with MockRouter(base_url="https://api.myst.ai/v1alpha2/") as mock_router:
+    with MockRouter(base_url=f"{myst.settings.MYST_API_HOST}/v1alpha2/") as mock_router:
         yield mock_router
 
 
