@@ -1,5 +1,5 @@
 from functools import singledispatch
-from typing import List, Optional, Union
+from typing import TYPE_CHECKING, List, Optional, Union
 
 from myst.client import get_client
 from myst.connectors.model_connector import ModelConnector
@@ -26,6 +26,9 @@ from myst.resources.resource import ShareableResource
 from myst.resources.source import Source
 from myst.resources.time_series import TimeSeries
 
+if TYPE_CHECKING:  # Avoid circular imports.
+    from myst.recipes.time_series_recipe import TimeSeriesRecipe
+
 
 @singledispatch
 def _parse_node(node: Union[TimeSeriesGet, SourceGet, OperationGet, ModelGet]) -> Node:
@@ -192,3 +195,18 @@ class Project(ShareableResource):
             axis_labels=axis_labels,
             description=description,
         )
+
+    def create_time_series_from_recipe(
+        self, recipe: "TimeSeriesRecipe", title: Optional[str] = None, description: Optional[str] = None
+    ) -> TimeSeries:
+        """Creates a new time series node in this project based on a provided recipe.
+
+        Args:
+            recipe: the recipe used to create the time series
+            title: the title of the time series; if none is given, the recipe will supply a sensible default
+            description: the description of the time series
+
+        Returns:
+            the newly created time series
+        """
+        return recipe.create(project=self, title=title, description=description)
