@@ -1,7 +1,7 @@
 from typing import TYPE_CHECKING, List, Optional, Union
 
-from myst import get_client
 from myst.adapters.timing import to_timing_create
+from myst.client import get_client
 from myst.core.data.time_array import TimeArray
 from myst.core.time.time import Time
 from myst.core.time.time_delta import TimeDelta
@@ -25,6 +25,7 @@ from myst.resources.node import Node
 from myst.resources.policy import TimeSeriesRunPolicy
 
 if TYPE_CHECKING:  # Avoid circular imports.
+    from myst.recipes.time_series_recipe import TimeSeriesRecipe
     from myst.resources.project import Project
 
 
@@ -92,6 +93,27 @@ class TimeSeries(Node):
 
         return TimeSeries.parse_obj(time_series.dict())
 
+    @classmethod
+    def create_from_recipe(
+        cls,
+        project: "Project",
+        recipe: "TimeSeriesRecipe",
+        title: Optional[str] = None,
+        description: Optional[str] = None,
+    ) -> "TimeSeries":
+        """Creates a new time series node based on a provided recipe.
+
+        Args:
+            project: the project in which to create the time series
+            recipe: the recipe used to create the time series
+            title: the title of the time series; if none is given, the recipe will supply a sensible default
+            description: the description of the time series
+
+        Returns:
+            the newly created time series
+        """
+        return recipe.create(project=project, title=title, description=description)
+
     @classmethod
     def get(cls, uuid: UUIDOrStr) -> "TimeSeries":
         """Gets a specific time series by its identifier."""
@@ -162,8 +184,8 @@ class TimeSeries(Node):
             uuid=str(self.uuid),
             start_time=start_time.to_iso_string(),
             end_time=end_time.to_iso_string(),
-            as_of_time=as_of_time and as_of_time.to_iso_string(),
-            as_of_offset=as_of_offset and as_of_offset.to_iso_string(),
+            as_of_time=as_of_time.to_iso_string() if as_of_time is not None else None,
+            as_of_offset=as_of_offset.to_iso_string() if as_of_offset is not None else None,
         )
 
         time_dataset = TimeDataset.parse_obj(time_series_query_result_get.time_dataset)
